@@ -1,13 +1,13 @@
 #' Plotting method for \code{survFitPredict} objects
 #'
 #' This is the generic \code{plot} S3 method for the
-#' \code{survFitPredict}.  It plots the predicted survival rate for each
+#' \code{survFitPredict}.  It plots the predicted survival probability for each
 #' concentration of the chemical compound in the provided dataset.
 #'
-#' The fitted curves represent the \strong{predicted survival rate} as a function
+#' The fitted curves represent the \strong{predicted survival probability} as a function
 #' of time for each concentration.
 #' The function plots both the 95\% credible band and the predicted survival
-#' rate over time.
+#' probability over time.
 #' If \code{spaghetti = TRUE}, the credible intervals are represented by two
 #' dotted lines limiting the credible band, and a spaghetti plot is added to this band.
 #' This spaghetti plot consists of the representation of simulated curves using parameter values
@@ -16,7 +16,7 @@
 #'
 #' @param x An object of class \code{survFitPredict}.
 #' @param xlab A label for the \eqn{X}-axis, by default \code{Time}.
-#' @param ylab A label for the \eqn{Y}-axis, by default \code{Survival rate}.
+#' @param ylab A label for the \eqn{Y}-axis, by default \code{Survival probability}.
 #' @param main A main title for the plot.
 #' @param spaghetti If \code{TRUE}, draws a set of survival curves using
 #' parameters drawn from the posterior distribution
@@ -61,7 +61,7 @@
 #'
 plot.survFitPredict <- function(x,
                                xlab = "Time",
-                               ylab = "Survival rate",
+                               ylab = "Survival probability",
                                main = NULL,
                                spaghetti = FALSE,
                                one.plot = FALSE,
